@@ -8,8 +8,8 @@
 
 #include <QApplication>
 
-#include <collection.h>
-#include <control.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Control>
 #include <filteractionjob_p.h>
 #include <kmailtransportakonadi/dispatcherinterface.h>
 #include <specialmailcollections.h>
